package edu.rice.comp211.laundry.iterator;

/**
 * An iterator that traverses a collection of objects of type T without modifying it. When an iterator traverses a list,
 * the list behaves as if it is circular with a dummy element between the last and first elements.
 */
public interface ReadIteratorI<T> {
   /**
    * Moves cursor to first element of the collection.  Places the cursor on dummy element if collection is empty.
    */
   void first();

   /**
    * Moves cursor to next element of the collection.  If current is the last element (atLast() == true) on entry,
    * moves cursor to dummy element following the last element.
    */
   void next();

   /**
    * @return true if the cursor is pointing to dummy element following the collection.
    */
   boolean atEnd();

   /**
    * @return true if the cursor is pointing to the first element of the collection. atEnd() => ! atStart().
    */
   boolean atStart();

   /**
    * @return the current element (pointed to by the cursor).
    * @throws IteratorException if the cursor is pointing to the dummy element.
    */
   T currentItem();
}
