/*
 * Copyright (C) 2006 Sun Microsystems, Inc. All rights reserved. Use is
 * subject to license terms.
 */

package edu.rice.comp211.laundry.ui;

import javax.swing.*;
import java.awt.*;
import java.util.MissingResourceException;

/**
 * Simple about box implementation. Pulls name and icon from resources.
 */
public final class AboutBox {
   private static AboutBox INSTANCE;

   public static AboutBox getInstance() {
      if (INSTANCE == null) {
         INSTANCE = new AboutBox();
      }
      return INSTANCE;
   }

   AboutBox() {
   }

   public void show(Window parent) {
      JDialog dialog;
      if (parent == null) {
         dialog = new JDialog();
      } else {
         dialog = new JDialog(parent);
      }
      JLabel backgroundLabel = new JLabel();
      JLabel applicationNameLabel = new JLabel();
      JLabel developerNameLabel = new JLabel();
      JPanel content = new JPanel();
      dialog.setContentPane(content);
      content.setBackground(new Color(90, 9, 6));
      String imageLoc;
      try {
         imageLoc = Application.getResourceAsString("aboutBox.loc");
      } catch (MissingResourceException mre) {
         imageLoc = null;
      }
      if (imageLoc == null) {
         imageLoc = "resources/aboutBox-background.jpg";
      }
      backgroundLabel.setIcon(new ImageIcon(getClass().getResource(imageLoc)));

      applicationNameLabel.setFont(new Font("Arial", 1, 20));
      applicationNameLabel.setForeground(new Color(255, 255, 255));
      applicationNameLabel.setText(Application.getInstance().getName());

      developerNameLabel.setFont(new Font("Arial", 0, 14));
      developerNameLabel.setForeground(new Color(255, 255, 255));
      developerNameLabel.setText(Application.getResourceAsString("aboutBox.developer"));

      GroupLayout layout = new GroupLayout(content);
      content.setLayout(layout);
      layout.setHorizontalGroup(
            layout.createParallelGroup()
                  .addComponent(applicationNameLabel, GroupLayout.Alignment.CENTER)
                  .addComponent(backgroundLabel)
                  .addComponent(developerNameLabel, GroupLayout.Alignment.CENTER)
      );
      layout.setVerticalGroup(
            layout.createParallelGroup()
                  .addGroup(layout.createSequentialGroup()
                  .addComponent(backgroundLabel, GroupLayout.PREFERRED_SIZE, 309, GroupLayout.PREFERRED_SIZE)
                  .addComponent(applicationNameLabel)
                  .addComponent(developerNameLabel)
                  .addContainerGap(GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
      );
      dialog.setTitle(Application.getResourceAsString("aboutBox.title"));
      dialog.setModal(true);
      dialog.pack();
      dialog.setLocationRelativeTo(null);
      dialog.setVisible(true);
      dialog.dispose();
   }
}